#ifndef _ADATA_SI5338_REGMAP_H
#define _ADATA_SI5338_REGMAP_H

#include <sdk_common.h>

#define SI5338_MAX_ENTRY_COUNT (512)

typedef struct _SI5338RegMap {
  uint16_t nEntryCount; /* Number of elements in 'pairs' array */
  struct {
    uint8_t nRegIndexLo;
    uint8_t nRegIndexHi;
    uint8_t nMaskValue;
    uint8_t nRegValue;
  } entries[1]; /* Variable length array */
} SI5338RegMap;

typedef enum _SI5338RegMapError {
  SI5338RegMapOk               = 0,
  SI5338RegMapBadFile          = 1,     /* Did not find any lines in expected format */
  SI5338RegMapAllocationError  = 0x100, /* Could not allocate memory for data structures */
  SI5338RegMapPermissionDenied = 0x101, /* Could not open file due to permissions of file */
  SI5338RegMapNotFound         = 0x102, /* File not found or at least one directory in path not found */
  SI5338RegMapOpenFailed       = 0x103, /* Failed to open file due to unexpected error */
  SI5338RegMapSeekError        = 0x104, /* Unspecified error occurred when seeking to beginning of file */
  SI5338RegMapReadError        = 0x105  /* Unspecified error occurred when reading file */
} SI5338RegMapError;

typedef enum _SI5338RegMapMessageType {
  SI5338RegMapMessageInfo = 0,
  SI5338RegMapMessageWarning = 1,
  SI5338RegMapMessageError = 2
} SI5338RegMapMessageType;

typedef void SI5338RegMapMessageCallback(const TCHAR* pMessage, SI5338RegMapMessageType type);

SI5338RegMapError SI5338RegMapReadFromFile(
  FILE* pFile,
  SI5338RegMapMessageCallback* pMessageCallback,
  SI5338RegMap** ppRegMap);

SI5338RegMapError SI5338RegMapRead(
  const TCHAR* pFileName,
  SI5338RegMapMessageCallback* pMessageCallback,
  SI5338RegMap** ppRegMap);

void SI5338RegMapDestroy(
  SI5338RegMap* pRegMap);

const TCHAR* SI5338RegMapGetErrorDesc(
  SI5338RegMapError nError);

#endif
